@@ -48,6 +48,8 @@ class Aperture(_BaseWithShade):
         * perimeter
         * min
         * max
+        * altitude
+        * azimuth
         * user_data
     """
     __slots__ = ('_geometry', '_parent', '_boundary_condition', '_is_operable')
@@ -240,6 +242,20 @@ class Aperture(_BaseWithShade):
         """Get a Point3D for the maximum of the bounding box around the object."""
         return self._max_with_shades(self._geometry)
 
+    @property
+    def altitude(self):
+        """Get the altitude of the geometry between +90 (up) and -90 (down)."""
+        return math.degrees(self._geometry.altitude)
+
+    @property
+    def azimuth(self):
+        """Get the azimuth of the geometry, between 0 and 360.
+
+        Given Y-axis as North, 0 = North, 90 = East, 180 = South, 270 = West
+        This will be zero if the Face3D is perfectly horizontal.
+        """
+        return math.degrees(self._geometry.azimuth)
+
     def horizontal_orientation(self, north_vector=Vector2D(0, 1)):
         """Get a number between 0 and 360 for the orientation of the aperture in degrees.
 
