@@ -65,6 +65,8 @@ class Face(_BaseWithShade):
         * max
         * aperture_area
         * aperture_ratio
+        * altitude
+        * azimuth
         * user_data
     """
     TYPES = face_types
@@ -345,6 +347,20 @@ class Face(_BaseWithShade):
         """
         return self.aperture_area / self.area
 
+    @property
+    def altitude(self):
+        """Get the altitude of the geometry between +90 (up) and -90 (down)."""
+        return math.degrees(self._geometry.altitude)
+
+    @property
+    def azimuth(self):
+        """Get the azimuth of the geometry, between 0 and 360.
+
+        Given Y-axis as North, 0 = North, 90 = East, 180 = South, 270 = West
+        This will be zero if the Face3D is perfectly horizontal.
+        """
+        return math.degrees(self._geometry.azimuth)
+
     def horizontal_orientation(self, north_vector=Vector2D(0, 1)):
         """Get a number between 0 and 360 for the orientation of the face in degrees.
 
@@ -1265,6 +1281,8 @@ class Face(_BaseWithShade):
             base['doors'] = [dr.to_dict(abridged, included_prop, include_plane)
                              for dr in self._doors]
         self._add_shades_to_dict(base, abridged, included_prop, include_plane)
+        if self.user_data is not None:
+            base['user_data'] = self.user_data
         return base
 
     def _acceptable_sub_face_check(self, sub_face_type=Aperture):
